summaryrefslogtreecommitdiff
path: root/src/screen.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/screen.h')
-rw-r--r--src/screen.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/screen.h b/src/screen.h
index ad8ddce..9c7c882 100644
--- a/src/screen.h
+++ b/src/screen.h
@@ -9,10 +9,12 @@ typedef struct _vwm_xwindow_t vwm_xwindow_t;
typedef XineramaScreenInfo vwm_screen_t; /* conveniently reuse the xinerama type for describing screens */
typedef enum _vwm_screen_rel_t {
- VWM_SCREEN_REL_RECT, /* return the screen the supplied rectangle x,y,w,h most resides in */
- VWM_SCREEN_REL_XWIN, /* return the screen the supplied window most resides in */
- VWM_SCREEN_REL_POINTER, /* return the screen the pointer resides in */
- VWM_SCREEN_REL_TOTAL, /* return the bounding rectangle of all screens as one */
+ VWM_SCREEN_REL_RECT, /* return the screen the supplied rectangle x,y,w,h most resides in */
+ VWM_SCREEN_REL_XWIN, /* return the screen the supplied window most resides in */
+ VWM_SCREEN_REL_XWIN_NEXT, /* return the next screen from the one the supplied window most resides in */
+ VWM_SCREEN_REL_XWIN_PREV, /* return the prev screen from the one the supplied window most resides in */
+ VWM_SCREEN_REL_POINTER, /* return the screen the pointer resides in */
+ VWM_SCREEN_REL_TOTAL, /* return the bounding rectangle of all screens as one */
} vwm_screen_rel_t;
const vwm_screen_t * vwm_screen_find(vwm_t *vwm, vwm_screen_rel_t rel, ...);
© All Rights Reserved